@@ -1,3 +1,5 @@
 from .linear_regression import LinearRegression
 from .logistic_regression import LogisticRegression
 from .softmax_regression import SoftmaxRegression
+from .recursive_sequential import RecursiveSequential
+from .auto_regression import AutoRegression
